/*
 *  Copyright 2009 Tsutomu YANO.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package jp.gihyo.wicket.component;

import org.apache.wicket.Page;
import org.apache.wicket.PageParameters;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.panel.Panel;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.ResourceModel;

/**
 *
 * @author Tsutomu YANO
 */
public class PagingLink extends Panel {

    protected IModel<Integer> pageNumberModel;
    protected Class<? extends Page> targetPageClass;

    public PagingLink(String id, Class<? extends Page> targetPageClass, IModel<Integer> pageNumberModel) {
        super(id);

        if(targetPageClass == null) throw new IllegalArgumentException("targetPageClass is missing.");
        if(pageNumberModel == null) throw new IllegalArgumentException("pageNumberModel is missing.");
        this.targetPageClass = targetPageClass;
        this.pageNumberModel = pageNumberModel;
        construct();
    }

    protected void construct() {
        Label prevLabel = new Label("prevLabel", new ResourceModel("prev"));
        Label nextLabel = new Label("nextLabel", new ResourceModel("next"));

        Link<Void> prevLink = new Link<Void>("prevLink") {
            @Override
            public void onClick() {
                setResponsePage(targetPageClass, new PageParameters("page=" + (pageNumberModel.getObject() + 1)));
            }

            @Override
            public boolean isEnabled() {
                Integer number = pageNumberModel.getObject();
                return number != null && number > 0;
            }
        };
        add(prevLink);
        prevLink.add(prevLabel);

        Link<Void> nextLink = new Link<Void>("nextLink") {
            @Override
            public void onClick() {
                setResponsePage(targetPageClass, new PageParameters("page=" + (pageNumberModel.getObject() - 1)));
            }

            @Override
            public boolean isEnabled() {
                Integer number = pageNumberModel.getObject();
                return number != null && number > 1;
            }
        };
        add(nextLink);
        nextLink.add(nextLabel);
    }
}
